# PutPublicEmailTemplateRequestToEmailType

Email receive type. * When the base object for the event is associated with `Account`, `toEmailType` can be any values in the enum list.  * When the base object for the event is not associated with `Account`, `toEmailType` must be `TenantAdmin`, `RunOwner`, or `SpecificEmail`. 

## Enum

* `BILLTOCONTACT` (value: `'BillToContact'`)

* `SOLDTOCONTACT` (value: `'SoldToContact'`)

* `SPECIFICEMAILS` (value: `'SpecificEmails'`)

* `TENANTADMIN` (value: `'TenantAdmin'`)

* `BILLTOANDSOLDTOCONTACTS` (value: `'BillToAndSoldToContacts'`)

* `RUNOWNER` (value: `'RunOwner'`)

* `ALLCONTACTS` (value: `'AllContacts'`)

* `INVOICEOWNERBILLTOCONTACT` (value: `'InvoiceOwnerBillToContact'`)

* `INVOICEOWNERSOLDTOCONTACT` (value: `'InvoiceOwnerSoldToContact'`)

* `INVOICEOWNERBILLTOANDSOLDTOCONTACTS` (value: `'InvoiceOwnerBillToAndSoldToContacts'`)

* `INVOICEOWNERALLCONTACTS` (value: `'InvoiceOwnerAllContacts'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


